@@ -96,7 +96,6 @@ public:
     KBookmarkManagerPrivate(bool bDocIsloaded)
         : m_doc(QStringLiteral("xbel"))
         , m_docIsLoaded(bDocIsloaded)
-        , m_update(false)
         , m_dirWatch(nullptr)
     {
     }
@@ -105,7 +104,6 @@ public:
     mutable QDomDocument m_toolbarDoc;
     QString m_bookmarksFile;
     mutable bool m_docIsLoaded;
-    bool m_update;
 
     KDirWatch *m_dirWatch; // for monitoring changes on bookmark files
 
@@ -130,8 +128,6 @@ KBookmarkManager::KBookmarkManager(const QString &bookmarksFile, QObject *parent
     : QObject(parent)
     , d(new KBookmarkManagerPrivate(false))
 {
-    d->m_update = true;
-
     Q_ASSERT(!bookmarksFile.isEmpty());
     d->m_bookmarksFile = bookmarksFile;
 
@@ -159,7 +155,7 @@ void KBookmarkManager::slotFileChanged(const QString &path)
         parse();
         // Tell our GUI
         // (emit where group is "" to directly mark the root menu as dirty)
-        Q_EMIT changed(QLatin1String(""), QString());
+        Q_EMIT changed(QLatin1String(""));
     }
 }
 
@@ -167,11 +163,6 @@ KBookmarkManager::~KBookmarkManager()
 {
 }
 
-void KBookmarkManager::setUpdate(bool update)
-{
-    d->m_update = update;
-}
-
 QDomDocument KBookmarkManager::internalDocument() const
 {
     if (!d->m_docIsLoaded) {
@@ -368,30 +359,7 @@ void KBookmarkManager::emitChanged(const KBookmarkGroup &group)
     // Tell the other processes too
     // qCDebug(KBOOKMARKS_LOG) << "KBookmarkManager::emitChanged : broadcasting change " << group.address();
 
-    Q_EMIT bookmarksChanged(group.address());
-
-    // We do get our own broadcast, so no need for this anymore
-    // emit changed( group );
-}
-
-void KBookmarkManager::emitConfigChanged()
-{
-    Q_EMIT bookmarkConfigChanged();
-}
-
-void KBookmarkManager::notifyCompleteChange(const QString &caller) // DBUS call
-{
-    if (!d->m_update) {
-        return;
-    }
-
-    // qCDebug(KBOOKMARKS_LOG) << "KBookmarkManager::notifyCompleteChange";
-    // The bk editor tells us we should reload everything
-    // Reparse
-    parse();
-    // Tell our GUI
-    // (emit where group is "" to directly mark the root menu as dirty)
-    Q_EMIT changed(QLatin1String(""), caller);
+    Q_EMIT changed(group.address());
 }
 
 ///////
